@@ -31,6 +31,7 @@ private Q_SLOTS:
         QTest::newRow("rot180") << QStringLiteral("pdf417_rot180.png");
         QTest::newRow("rot270") << QStringLiteral("pdf417_rot270.png");
         QTest::newRow("flipped") << QStringLiteral("pdf417_flipped.png");
+        QTest::newRow("partial cropped") << QStringLiteral("pdf417_partial_cropped.png");
     }
 
     void testPDF417()
@@ -54,6 +55,11 @@ private Q_SLOTS:
 #ifdef HAVE_ZXING
         QCOMPARE(decoder.decodeString(img, BarcodeDecoder::Aztec), QStringLiteral("This is an example Aztec symbol for Wikipedia."));
 #endif
+        img.load(QStringLiteral(SOURCE_DIR "/barcodes/aztec-partial-quiet-zone.png"));
+        QVERIFY(!img.isNull());
+#ifdef HAVE_ZXING
+        QCOMPARE(decoder.decodeString(img, BarcodeDecoder::Aztec), QStringLiteral("KF5::Prison - The KDE barcode generation framework."));
+#endif
 
         img.load(QStringLiteral(SOURCE_DIR "/barcodes/uic918-3star.png"));
         QVERIFY(!img.isNull());
@@ -71,6 +77,8 @@ private Q_SLOTS:
 
             QTest::newRow("1") << QStringLiteral("qrcode1.png") << QStringLiteral("M$K0YGV0G");
             QTest::newRow("2") << QStringLiteral("qrcode2.png") << QStringLiteral("KZEXO4HRE");
+            // individual lines have non-square features (found e.g. in Renfe tickets)
+            QTest::newRow("3") << QStringLiteral("qrcode-scale-artifacts.png") << QStringLiteral("M$K0YGV0G");
     }
 
     void testQRCode()
