@@ -227,11 +227,7 @@ void KItinerary::Generator::AirportDbGenerator::indexNames()
     for (auto it = m_airportMap.begin(); it != m_airportMap.end(); ++it) {
         auto l = StringUtil::normalize(it.value().label + QLatin1Char(' ') + it.value().alias)
                  .split(QRegularExpression(QStringLiteral("[ 0-9/'\"\\(\\)&\\,.–„-]")),
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                   Qt::SkipEmptyParts
-#else
-                  QString::SkipEmptyParts
-#endif
                 );
         std::for_each(l.begin(), l.end(), [](QString &s) {
             s = s.toCaseFolded();
@@ -297,7 +293,7 @@ bool AirportDbGenerator::generate(QIODevice* out)
     indexNames();
 
     // step 4 generate code
-    CodeGen::writeLicenseHeader(out);
+    CodeGen::writeLicenseHeaderOSM(out);
     out->write(R"(
 
 #include "airportdb.h"
